# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionJobLogResponseLog(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'exit_code': 'int',
        'hwinfo': 'dict(str, object)',
        'script_sha256': 'str',
        'stderr': 'str',
        'stdout': 'dict(str, object)',
        'usage': 'dict(str, object)',
        'os_release': 'InspectionJobLogResponseLogOsRelease',
        'runtime_environment': 'InspectionJobLogResponseLogRuntimeEnvironment'
    }

    attribute_map = {
        'exit_code': 'exit_code',
        'hwinfo': 'hwinfo',
        'script_sha256': 'script_sha256',
        'stderr': 'stderr',
        'stdout': 'stdout',
        'usage': 'usage',
        'os_release': 'os_release',
        'runtime_environment': 'runtime_environment'
    }

    def __init__(self, exit_code=None, hwinfo=None, script_sha256=None, stderr=None, stdout=None, usage=None, os_release=None, runtime_environment=None):  # noqa: E501
        """InspectionJobLogResponseLog - a model defined in OpenAPI"""  # noqa: E501

        self._exit_code = None
        self._hwinfo = None
        self._script_sha256 = None
        self._stderr = None
        self._stdout = None
        self._usage = None
        self._os_release = None
        self._runtime_environment = None
        self.discriminator = None

        self.exit_code = exit_code
        self.hwinfo = hwinfo
        self.script_sha256 = script_sha256
        self.stderr = stderr
        self.stdout = stdout
        self.usage = usage
        self.os_release = os_release
        self.runtime_environment = runtime_environment

    @property
    def exit_code(self):
        """Gets the exit_code of this InspectionJobLogResponseLog.  # noqa: E501

        Exit code of user provided script (matches exit code of the inspect job)  # noqa: E501

        :return: The exit_code of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this InspectionJobLogResponseLog.

        Exit code of user provided script (matches exit code of the inspect job)  # noqa: E501

        :param exit_code: The exit_code of this InspectionJobLogResponseLog.  # noqa: E501
        :type: int
        """
        if exit_code is None:
            raise ValueError("Invalid value for `exit_code`, must not be `None`")  # noqa: E501

        self._exit_code = exit_code

    @property
    def hwinfo(self):
        """Gets the hwinfo of this InspectionJobLogResponseLog.  # noqa: E501

        Hardware information as provided by Amun's hwinfo.  # noqa: E501

        :return: The hwinfo of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._hwinfo

    @hwinfo.setter
    def hwinfo(self, hwinfo):
        """Sets the hwinfo of this InspectionJobLogResponseLog.

        Hardware information as provided by Amun's hwinfo.  # noqa: E501

        :param hwinfo: The hwinfo of this InspectionJobLogResponseLog.  # noqa: E501
        :type: dict(str, object)
        """
        if hwinfo is None:
            raise ValueError("Invalid value for `hwinfo`, must not be `None`")  # noqa: E501

        self._hwinfo = hwinfo

    @property
    def script_sha256(self):
        """Gets the script_sha256 of this InspectionJobLogResponseLog.  # noqa: E501

        SHA 256 digest of user provided script  # noqa: E501

        :return: The script_sha256 of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: str
        """
        return self._script_sha256

    @script_sha256.setter
    def script_sha256(self, script_sha256):
        """Sets the script_sha256 of this InspectionJobLogResponseLog.

        SHA 256 digest of user provided script  # noqa: E501

        :param script_sha256: The script_sha256 of this InspectionJobLogResponseLog.  # noqa: E501
        :type: str
        """
        if script_sha256 is None:
            raise ValueError("Invalid value for `script_sha256`, must not be `None`")  # noqa: E501

        self._script_sha256 = script_sha256

    @property
    def stderr(self):
        """Gets the stderr of this InspectionJobLogResponseLog.  # noqa: E501

        Standard error output produced by user provided script.  # noqa: E501

        :return: The stderr of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: str
        """
        return self._stderr

    @stderr.setter
    def stderr(self, stderr):
        """Sets the stderr of this InspectionJobLogResponseLog.

        Standard error output produced by user provided script.  # noqa: E501

        :param stderr: The stderr of this InspectionJobLogResponseLog.  # noqa: E501
        :type: str
        """
        if stderr is None:
            raise ValueError("Invalid value for `stderr`, must not be `None`")  # noqa: E501

        self._stderr = stderr

    @property
    def stdout(self):
        """Gets the stdout of this InspectionJobLogResponseLog.  # noqa: E501

        Standard output prodiced by user provided script.  # noqa: E501

        :return: The stdout of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._stdout

    @stdout.setter
    def stdout(self, stdout):
        """Sets the stdout of this InspectionJobLogResponseLog.

        Standard output prodiced by user provided script.  # noqa: E501

        :param stdout: The stdout of this InspectionJobLogResponseLog.  # noqa: E501
        :type: dict(str, object)
        """
        if stdout is None:
            raise ValueError("Invalid value for `stdout`, must not be `None`")  # noqa: E501

        self._stdout = stdout

    @property
    def usage(self):
        """Gets the usage of this InspectionJobLogResponseLog.  # noqa: E501

        Utilization of resources such as user-space or kernel-space CPU time, context switches, shared memory size or page faults (and others).   # noqa: E501

        :return: The usage of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this InspectionJobLogResponseLog.

        Utilization of resources such as user-space or kernel-space CPU time, context switches, shared memory size or page faults (and others).   # noqa: E501

        :param usage: The usage of this InspectionJobLogResponseLog.  # noqa: E501
        :type: dict(str, object)
        """
        if usage is None:
            raise ValueError("Invalid value for `usage`, must not be `None`")  # noqa: E501

        self._usage = usage

    @property
    def os_release(self):
        """Gets the os_release of this InspectionJobLogResponseLog.  # noqa: E501


        :return: The os_release of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: InspectionJobLogResponseLogOsRelease
        """
        return self._os_release

    @os_release.setter
    def os_release(self, os_release):
        """Sets the os_release of this InspectionJobLogResponseLog.


        :param os_release: The os_release of this InspectionJobLogResponseLog.  # noqa: E501
        :type: InspectionJobLogResponseLogOsRelease
        """
        if os_release is None:
            raise ValueError("Invalid value for `os_release`, must not be `None`")  # noqa: E501

        self._os_release = os_release

    @property
    def runtime_environment(self):
        """Gets the runtime_environment of this InspectionJobLogResponseLog.  # noqa: E501


        :return: The runtime_environment of this InspectionJobLogResponseLog.  # noqa: E501
        :rtype: InspectionJobLogResponseLogRuntimeEnvironment
        """
        return self._runtime_environment

    @runtime_environment.setter
    def runtime_environment(self, runtime_environment):
        """Sets the runtime_environment of this InspectionJobLogResponseLog.


        :param runtime_environment: The runtime_environment of this InspectionJobLogResponseLog.  # noqa: E501
        :type: InspectionJobLogResponseLogRuntimeEnvironment
        """
        if runtime_environment is None:
            raise ValueError("Invalid value for `runtime_environment`, must not be `None`")  # noqa: E501

        self._runtime_environment = runtime_environment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionJobLogResponseLog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionResultResponseMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'analyzer': 'str',
        'analyzer_version': 'str',
        'arguments': 'dict(str, object)',
        'datetime': 'str',
        'distribution': 'InspectionResultResponseMetadataDistribution',
        'hostname': 'str',
        'python': 'object'
    }

    attribute_map = {
        'analyzer': 'analyzer',
        'analyzer_version': 'analyzer_version',
        'arguments': 'arguments',
        'datetime': 'datetime',
        'distribution': 'distribution',
        'hostname': 'hostname',
        'python': 'python'
    }

    def __init__(self, analyzer=None, analyzer_version=None, arguments=None, datetime=None, distribution=None, hostname=None, python=None):  # noqa: E501
        """InspectionResultResponseMetadata - a model defined in OpenAPI"""  # noqa: E501

        self._analyzer = None
        self._analyzer_version = None
        self._arguments = None
        self._datetime = None
        self._distribution = None
        self._hostname = None
        self._python = None
        self.discriminator = None

        self.analyzer = analyzer
        self.analyzer_version = analyzer_version
        self.arguments = arguments
        self.datetime = datetime
        self.distribution = distribution
        self.hostname = hostname
        self.python = python

    @property
    def analyzer(self):
        """Gets the analyzer of this InspectionResultResponseMetadata.  # noqa: E501

        Analyzer name which handled inspection.  # noqa: E501

        :return: The analyzer of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._analyzer

    @analyzer.setter
    def analyzer(self, analyzer):
        """Sets the analyzer of this InspectionResultResponseMetadata.

        Analyzer name which handled inspection.  # noqa: E501

        :param analyzer: The analyzer of this InspectionResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if analyzer is None:
            raise ValueError("Invalid value for `analyzer`, must not be `None`")  # noqa: E501

        self._analyzer = analyzer

    @property
    def analyzer_version(self):
        """Gets the analyzer_version of this InspectionResultResponseMetadata.  # noqa: E501

        Version of analyzer handling inspection.  # noqa: E501

        :return: The analyzer_version of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._analyzer_version

    @analyzer_version.setter
    def analyzer_version(self, analyzer_version):
        """Sets the analyzer_version of this InspectionResultResponseMetadata.

        Version of analyzer handling inspection.  # noqa: E501

        :param analyzer_version: The analyzer_version of this InspectionResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if analyzer_version is None:
            raise ValueError("Invalid value for `analyzer_version`, must not be `None`")  # noqa: E501

        self._analyzer_version = analyzer_version

    @property
    def arguments(self):
        """Gets the arguments of this InspectionResultResponseMetadata.  # noqa: E501

        Arguments passed to analyzer.  # noqa: E501

        :return: The arguments of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this InspectionResultResponseMetadata.

        Arguments passed to analyzer.  # noqa: E501

        :param arguments: The arguments of this InspectionResultResponseMetadata.  # noqa: E501
        :type: dict(str, object)
        """
        if arguments is None:
            raise ValueError("Invalid value for `arguments`, must not be `None`")  # noqa: E501

        self._arguments = arguments

    @property
    def datetime(self):
        """Gets the datetime of this InspectionResultResponseMetadata.  # noqa: E501

        Date and time of inspection end in ISO format.  # noqa: E501

        :return: The datetime of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._datetime

    @datetime.setter
    def datetime(self, datetime):
        """Sets the datetime of this InspectionResultResponseMetadata.

        Date and time of inspection end in ISO format.  # noqa: E501

        :param datetime: The datetime of this InspectionResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if datetime is None:
            raise ValueError("Invalid value for `datetime`, must not be `None`")  # noqa: E501

        self._datetime = datetime

    @property
    def distribution(self):
        """Gets the distribution of this InspectionResultResponseMetadata.  # noqa: E501


        :return: The distribution of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: InspectionResultResponseMetadataDistribution
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """Sets the distribution of this InspectionResultResponseMetadata.


        :param distribution: The distribution of this InspectionResultResponseMetadata.  # noqa: E501
        :type: InspectionResultResponseMetadataDistribution
        """
        if distribution is None:
            raise ValueError("Invalid value for `distribution`, must not be `None`")  # noqa: E501

        self._distribution = distribution

    @property
    def hostname(self):
        """Gets the hostname of this InspectionResultResponseMetadata.  # noqa: E501

        Pod name where the inspection was done.  # noqa: E501

        :return: The hostname of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this InspectionResultResponseMetadata.

        Pod name where the inspection was done.  # noqa: E501

        :param hostname: The hostname of this InspectionResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if hostname is None:
            raise ValueError("Invalid value for `hostname`, must not be `None`")  # noqa: E501

        self._hostname = hostname

    @property
    def python(self):
        """Gets the python of this InspectionResultResponseMetadata.  # noqa: E501


        :return: The python of this InspectionResultResponseMetadata.  # noqa: E501
        :rtype: object
        """
        return self._python

    @python.setter
    def python(self, python):
        """Sets the python of this InspectionResultResponseMetadata.


        :param python: The python of this InspectionResultResponseMetadata.  # noqa: E501
        :type: object
        """
        if python is None:
            raise ValueError("Invalid value for `python`, must not be `None`")  # noqa: E501

        self._python = python

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionResultResponseMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionSpecificationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parameters': 'object',
        'specification': 'InspectionSpecification',
        'created': 'str'
    }

    attribute_map = {
        'parameters': 'parameters',
        'specification': 'specification',
        'created': 'created'
    }

    def __init__(self, parameters=None, specification=None, created=None):  # noqa: E501
        """InspectionSpecificationResponse - a model defined in OpenAPI"""  # noqa: E501

        self._parameters = None
        self._specification = None
        self._created = None
        self.discriminator = None

        self.parameters = parameters
        self.specification = specification
        self.created = created

    @property
    def parameters(self):
        """Gets the parameters of this InspectionSpecificationResponse.  # noqa: E501

        Parameters echoed back to user (with default parameters if omitted).   # noqa: E501

        :return: The parameters of this InspectionSpecificationResponse.  # noqa: E501
        :rtype: object
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this InspectionSpecificationResponse.

        Parameters echoed back to user (with default parameters if omitted).   # noqa: E501

        :param parameters: The parameters of this InspectionSpecificationResponse.  # noqa: E501
        :type: object
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    @property
    def specification(self):
        """Gets the specification of this InspectionSpecificationResponse.  # noqa: E501


        :return: The specification of this InspectionSpecificationResponse.  # noqa: E501
        :rtype: InspectionSpecification
        """
        return self._specification

    @specification.setter
    def specification(self, specification):
        """Sets the specification of this InspectionSpecificationResponse.


        :param specification: The specification of this InspectionSpecificationResponse.  # noqa: E501
        :type: InspectionSpecification
        """
        if specification is None:
            raise ValueError("Invalid value for `specification`, must not be `None`")  # noqa: E501

        self._specification = specification

    @property
    def created(self):
        """Gets the created of this InspectionSpecificationResponse.  # noqa: E501

        Creation time of an inspection run.  # noqa: E501

        :return: The created of this InspectionSpecificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this InspectionSpecificationResponse.

        Creation time of an inspection run.  # noqa: E501

        :param created: The created of this InspectionSpecificationResponse.  # noqa: E501
        :type: str
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionSpecificationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from amun.swagger_client.amun.debug_api import DebugApi
from amun.swagger_client.amun.inspection_api import InspectionApi



#!/usr/bin/env python3
# amun
# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""A simple wrapper around models to simplify inspection submission."""


from typing import Any
from typing import Dict
from typing import List
from typing import Optional
from typing import Tuple

from .swagger_client import InspectionApi
from .swagger_client import InspectionSpecification
from .swagger_client import Configuration
from .swagger_client import ApiClient


def instantiate_inspection_api(amun_api_url: str) -> InspectionApi:
    """Instantiate InspectionApi for communicating with Amun API."""
    # Adjust remote to communicate with:
    configuration = Configuration()
    configuration.host = amun_api_url
    api_client = ApiClient(configuration)

    # Use the customized API client to talk to the remote API with the adjusted host.
    return InspectionApi(api_client)


def get_inspection_status(amun_api_url: str, inspection_id: str) -> dict:
    """Get status dictionary of the given inspection."""
    api_instance = instantiate_inspection_api(amun_api_url)
    api_response = api_instance.get_inspection_status(inspection_id)
    api_response = api_response.to_dict()
    api_response.pop('parameters', None)
    return api_response


def is_inspection_finished(amun_api_url: str, inspection_id: str) -> bool:
    """Check if the given inspection is finished."""
    status = get_inspection_status(amun_api_url, inspection_id)
    build_finished = status['build']['state'] == 'terminated'
    # Inspection is finished if the given job is finished or was not requested to run.
    job_finished = status['job'] is None or status['job']['state'] == 'terminated'
    return build_finished and job_finished


def has_inspection_job(amun_api_url: str, inspection_id: str) -> bool:
    """Check if the given inspection has assigned job."""
    status = get_inspection_status(amun_api_url, inspection_id)
    return status['job'] is not None


def inspect(
    amun_api_url: str,
    base: str,
    *,
    identifier: Optional[str] = None,
    files: Optional[List[Dict[str, Any]]] = None,
    packages: Optional[List[str]] = None,
    python_packages: Optional[List[str]] = None,
    python: Optional[Dict[str, Any]] = None,
    build: Optional[Dict[str, Any]] = None,
    run: Optional[Dict[str, Any]] = None,
    script: Optional[str] = None
) -> Dict[str, Any]:
    """Submit an analysis to the inspection endpoint."""
    api_instance = instantiate_inspection_api(amun_api_url)

    specification = InspectionSpecification(
        base=base,
        packages=packages,
        python_packages=python_packages,
        python=python,
        files=files,
        script=script,
        build=build,
        run=run,
        identifier=identifier,
    )

    api_response = api_instance.post_inspection(specification)
    return api_response.to_dict()


def get_inspection_build_log(amun_api_url: str, inspection_id: str) -> str:
    """Get log of an inspection build, the inspection has to be successful."""
    api_instance = instantiate_inspection_api(amun_api_url)
    api_response = api_instance.get_inspection_build_log(inspection_id)
    return api_response.to_dict()['log']


def get_inspection_job_log(amun_api_url: str, inspection_id: str) -> dict:
    """Get log of an inspection job, the inspection has to be successful."""
    api_instance = instantiate_inspection_api(amun_api_url)
    api_response = api_instance.get_inspection_job_log(inspection_id)
    return api_response.to_dict()['log']


def get_inspection_specification(amun_api_url: str, inspection_id: str) -> Tuple[dict, str]:
    """Get specification of an inspection, the inspection has to be successful."""
    api_instance = instantiate_inspection_api(amun_api_url)
    api_response = api_instance.get_inspection_specification(inspection_id)
    api_response = api_response.to_dict()
    return api_response['specification'], api_response['created']
